<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>Shape</name>
    <message>
        <location filename="../Shape.js" line="+75"/>
        <source>Shape Tools</source>
        <translation>Muototyökalut</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show shape tools</source>
        <translation>Näytä muototyökalut</translation>
    </message>
    <message>
        <source>Show line tools</source>
        <translation type="vanished">Näytä viivatyökalut</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Shape</source>
        <translation>&amp;Muoto</translation>
    </message>
    <message>
        <location filename="../Shape.ui" line="+17"/>
        <source>Create polyline</source>
        <translation>Luo moniviiva</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Fill</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
